<?php
class NewsComments extends Module 
{
    private $_postErrors = array();
    private $_sef;
    private $_configuration;


    public function __construct() 
    {
        $this->name = 'newscomments';
        $this->tab = 'News';
        $this->version = '0.8';

        parent::__construct();

        $this->displayName = $this->l('News Comments module');
        $this->description = $this->l('Allows your visitors and customers to comment on your news');
        $this->confirmUninstall = $this->l('Are you sure you want to delete all the comments?');
        $this->_sef = intval(Configuration::get('PS_REWRITING_SETTINGS'));
        
        $this->_configuration = Configuration::getMultiple(array(
		    'NEWSCOMMENTS_ADGROUP',
            'NEWSCOMMENTS_ALLOWGUEST',
            'NEWSCOMMENTS_MODGUEST',
            'NEWSCOMMENTS_CAPTCHAGUEST',
            'NEWSCOMMENTS_MODREG',
            'NEWSCOMMENTS_CAPTCHAREG',
            'NEWSCOMMENTS_REGDELAY',
            'NEWSCOMMENTS_GUESTDELAY'
		));
    }


    public function install() 
    {
        if(!Hook::get('newsFooter')) {
			if (!Db::getInstance()->Execute('INSERT INTO `'._DB_PREFIX_.'hook` VALUES (\'\', \'newsFooter\', \'News Entry Footer Hook\', \'\', \'1\')')) {
				return false;
			}
		}
		
        if (parent::install() == false
            OR !$this->registerHook('newsFooter')
            OR !$this->registerHook('header')
            OR !Configuration::updateValue('NEWSCOMMENTS_ADGROUP', 0)
            OR !Configuration::updateValue('NEWSCOMMENTS_ALLOWGUEST', 0)
            OR !Configuration::updateValue('NEWSCOMMENTS_MODGUEST', 1)
            OR !Configuration::updateValue('NEWSCOMMENTS_CAPTCHAGUEST', 1)
            OR !Configuration::updateValue('NEWSCOMMENTS_GUESTDELAY', 10)
            OR !Configuration::updateValue('NEWSCOMMENTS_MODREG', 0)
            OR !Configuration::updateValue('NEWSCOMMENTS_REGDELAY', 10)
            OR !Configuration::updateValue('NEWSCOMMENTS_CAPTCHAREG', 0))
        {
             return false;
        }

        $query = 'CREATE TABLE `' . _DB_PREFIX_ . 'newscomments` (
        `id_entry_comment` int(10) unsigned NOT NULL auto_increment,
        `id_entry` int(10) unsigned NOT NULL,
        `id_parent` int(10) unsigned NOT NULL,
        `username` varchar(32) NOT NULL,
        `email` varchar(128) NOT NULL,
        `id_customer` int(10) unsigned NOT NULL,
        `content` text NOT NULL,
        `validate` tinyint(1) NOT NULL,
        `date_add` datetime NOT NULL,
        PRIMARY KEY (`id_entry_comment`)
        ) ENGINE=MyISAM  DEFAULT CHARSET=utf8';

        if (!Db::getInstance()->Execute($query))
        {
             return false;
        }

         return true;
    }


    public function uninstall() 
    {
        if (parent::uninstall() == false) {
             return false;
        }

        if (!Db::getInstance()->Execute('DROP TABLE `' . _DB_PREFIX_ . 'newscomments`')) {
             return false;
        }
        
        if(!Configuration::deleteByName('NEWSCOMMENTS_ADGROUP')
        OR !Configuration::deleteByName('NEWSCOMMENTS_ALLOWGUEST')
        OR !Configuration::deleteByName('NEWSCOMMENTS_MODGUEST')
        OR !Configuration::deleteByName('NEWSCOMMENTS_CAPTCHAGUEST')
        OR !Configuration::deleteByName('NEWSCOMMENTS_CAPTCHAGUEST')
        OR !Configuration::deleteByName('NEWSCOMMENTS_MODREG')
        OR !Configuration::deleteByName('NEWSCOMMENTS_REGDELAY')
        OR !Configuration::deleteByName('NEWSCOMMENTS_GUESTDELAY')) {
			return false;
        }

        return true;
    }
    
    
    public function displaySettings()
    {
        global $cookie;
        $groups = Group::getGroups($cookie->id_lang);
        array_unshift($groups, array('id_group' => 0, 'name' => $this->l('Not specified')));

        $return = array(
            'NEWSCOMMENTS_ADGROUP' => array(
                'title'         => $this->l('Comments moderators group'), 
                'desc'          => $this->l('Every member of this group will be able to approve and delete comments through front office'), 
                'cast'          => 'intval', 
                'size'          => 3, 
                'type'          => 'select', 
                'list'          => $groups, 
                'identifier'    => 'id_group'
            ),
	        'NEWSCOMMENTS_MODREG' => array(
	            'title'         => $this->l('Registered users moderation:'), 
	            'desc'          => $this->l('Require moderator or administrator to validate comments by registered users before posting them'), 
	            'validation'    => 'isBool', 
	            'cast'          => 'intval', 
	            'type'          => 'bool'
	        ),
		    'NEWSCOMMENTS_CAPTCHAREG' => array(
		        'title'         => $this->l('Show captcha to registered users:'), 
		        'desc'          => $this->l('Require registered users to enter captcha code'), 
		        'validation'    => 'isBool', 
		        'cast'          => 'intval', 
		        'type'          => 'bool'
		    ),
		    'NEWSCOMMENTS_REGDELAY' => array(
		        'title'         => $this->l('Registered users flood protection:'), 
		        'desc'          => $this->l('How much time (min) a registered user have to wait before posting another comment'), 
		        'cast'          => 'intval', 
		        'size'          => 3, 
		        'type'          => 'text', 
		        'suffix'        => ' минут'
		    ),
		    'NEWSCOMMENTS_ALLOWGUEST' => array(
		        'title'         => $this->l('Allow comments by guests:'), 
		        'desc'          => $this->l('Allow or disallow the ability to post comments for unregistered users'), 
		        'validation'    => 'isBool', 
		        'cast'          => 'intval', 
		        'type'          => 'bool'
		    ),
		    'NEWSCOMMENTS_MODGUEST' => array(
		        'title'         => $this->l('Guest moderation:'), 
		        'desc'          => $this->l('Require moderator or administrator to validate comments by guests before posting them'), 
		        'validation'    => 'isBool', 
		        'cast'          => 'intval', 
		        'type'          => 'bool'
		    ),
		    'NEWSCOMMENTS_CAPTCHAGUEST' => array(
		        'title'         => $this->l('Show captcha to guests:'), 
		        'desc'          => $this->l('Require guests to enter captcha code'), 
		        'validation'    => 'isBool', 
		        'cast'          => 'intval', 
		        'type'          => 'bool'
		    ),
		    'NEWSCOMMENTS_GUESTDELAY' => array(
		        'title'         => $this->l('Guests flood protection:'), 
		        'desc'          => $this->l('How much time (min) a guest have to wait before posting another comment'), 
		        'cast'          => 'intval', 
		        'size'          => 3, 
		        'type'          => 'text', 
		        'suffix'        => ' минут'
		    )
		);
		return $return;
    }


    public function deleteComment($comment_id) 
    {
        if(!Validate::isUnsignedInt($comment_id)) {
            return false;
        }
        
        if(!Db::getInstance()->Execute('
        DELETE FROM `' . _DB_PREFIX_ . 'newscomments` 
        WHERE `id_entry_comment` = ' . intval($comment_id))) 
        {
                $this->_postErrors[] = $this->l('Could not delete a comment');
                return false;
        } elseif (Db::getInstance()->getValue('
            SELECT `id_entry_comment` FROM `' . _DB_PREFIX_ . 'newscomments` 
            WHERE `id_parent` = ' . intval($comment_id))) {
            if(!Db::getInstance()->Execute('
                DELETE FROM `' . _DB_PREFIX_ . 'newscomments` 
                WHERE `id_parent` = ' . intval($comment_id))) {
                $this->_postErrors[] = $this->l('Could not delete comment replies');
                return false;
            }
        }
        return true;
    }


    public function changeStatus($comment_id) 
    {
        $sql = '
        UPDATE `' . _DB_PREFIX_ . 'newscomments`
        SET `validate` = !`validate`
        WHERE `id_entry_comment` = ' . intval($comment_id);

        if(!Db::getInstance()->Execute($sql)) 
        {
            $this->_postErrors[] = $this->l('Could not change comment status');
            return false;
        }

        return true;
    }
    
    
    private function checkIfModerator($customer_id, $group_id)
    {
        $result = Db::getInstance()->getRow('
		SELECT count(cg.`id_group`) as nb
		FROM '._DB_PREFIX_.'customer_group cg
		WHERE cg.`id_customer` = '.intval($customer_id).'
		AND cg.`id_group` = '.intval($group_id));
		return $result['nb'];
    }
    
    
	private function _frontOfficePostProcess()
	{
		global $smarty, $cookie, $errors;
		
		$moderatorGroup = intval($this->_configuration['NEWSCOMMENTS_ADGROUP']);
		$moderator = $this->checkIfModerator($cookie->id_customer, $moderatorGroup);
		require_once(dirname(__FILE__).'/NewsComment.php');
		if (Tools::isSubmit('submitMessage')) {
		    $comment = new NewsComment();
		    if (!$comment->id_entry = Tools::getValue('id_entry')) {
		       $errors[] = $this->l('Strange... Are you a haxor?.'); 
		    } elseif(!Validate::isUnsignedInt($comment->id_entry)) {
		        $errors[] = $this->l('Strange... Are you a haxor?.'); 
		    }
		    
		    $comment->id_parent = Tools::getValue('reply_id', 0);
		    if(!Validate::isUnsignedInt($comment->id_parent)) {
		        $errors[] = $this->l('Strange... Are you a haxor?.'); 
		    }
		    
			if (!$comment->content = Tools::getValue('content')) {
			    $errors[] = $this->l('You didn\'t write anything.');
			} elseif (!Validate::isMessage($comment->content)) {
			    $errors[] = $this->l('Wrong comment message, please use text only.');
			} elseif (strlen($comment->content) > 65535) {
			    $errors[] = $this->l('Your message is too long.');
			}
			
			/* Special validation rules for non-registered users */
			if(!$cookie->id_customer && intval($this->_configuration['NEWSCOMMENTS_ALLOWGUEST']) == 1) {
			    $comment->validate = intval($this->_configuration['NEWSCOMMENTS_MODGUEST']) == 1 ? 0 : 1;
			    
			    if(!$comment->email = Tools::getValue('email')) {
			        $errors[] = $this->l('Non-registered users must provide email to post comments.');
			    } elseif(!Validate::isEmail($comment->email)) {
			        $errors[] = $this->l('Provided email is incorrect.');
			    } elseif (Customer::getByEmail($comment->email)) {
			        $errors[] = $this->l('Provided email belongs to one of registered customers.');
			    }
			        
			    if(!$comment->username = Tools::getValue('username')) {
			        $errors[] = $this->l('You didn\'t specify your username.');
			    } elseif (!Validate::isName($comment->username)) {
			        $errors[] = $this->l('Username you provided contains forbidden characters.');
			    }
			    
			    if(intval($this->_configuration['NEWSCOMMENTS_CAPTCHAGUEST']) == 1 && (!isset($_SESSION['captcha_keystring']) || $_SESSION['captcha_keystring'] != $_POST['keystring'])) {
			        $errors[] = $this->l('The captcha code you\'ve entered is invalid.');
			    }
			    
			    if(isset($_SESSION['ps_floodprotection']) AND ($_SESSION['ps_floodprotection'] >= time())) {
			        $errors[] = $this->l('You have to wait') . ' ' . intval($this->_configuration['NEWSCOMMENTS_GUESTDELAY']) . ' ' . $this->l('minutes before posting new comment');
			    }
			    
			} elseif($cookie->id_customer) {
			    if($moderator) {
			        $comment->validate = 1;
			    } else {
			        if(intval($this->_configuration['NEWSCOMMENTS_CAPTCHAREG']) == 1 && (!isset($_SESSION['captcha_keystring']) || $_SESSION['captcha_keystring'] != $_POST['keystring'])) {
			            $errors[] = $this->l('The captcha code you\'ve entered is invalid.');
			        }
			        
			        if(isset($_SESSION['ps_regfloodprotection']) AND ($_SESSION['ps_regfloodprotection'] >= time())) {
			            $errors[] = $this->l('You have to wait') . ' ' . intval($this->_configuration['NEWSCOMMENTS_REGDELAY']) . ' ' . $this->l('minutes before posting new comment');
			        }
			        
			        $comment->validate = intval($this->_configuration['NEWSCOMMENTS_MODREG']) == 1 ? 0 : 1;
			    }
			    $comment->id_customer = intval($cookie->id_customer);
			} else {
			    $errors[] = $this->l('Only registered customers can post comments.');
			}
			
			if(!sizeof($errors)) {
			    $url = 'http' . (isset($_SERVER['HTTPS']) ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
			    if (!$comment->save()) {
					$errors[] = $this->l('An error occured while saving your comment.');
				} else {
				    if(!$moderator && $cookie->id_customer) {
				        $_SESSION['ps_regfloodprotection'] = time() + $this->_configuration['NEWSCOMMENTS_REGDELAY'] * 60;
				    } elseif (!$moderator) {
				        $_SESSION['ps_floodprotection'] = time() + $this->_configuration['NEWSCOMMENTS_GUESTDELAY'] * 60;
				    }
				    $url .= '&comment=p';
				    if($cookie->id_customer && (!$moderator && intval($this->_configuration['NEWSCOMMENTS_MODREG']) == 1) 
				    OR (!$cookie->id_customer && intval($this->_configuration['NEWSCOMMENTS_MODGUEST']) == 1)) {
				            $url .= 'v';
				    }
					Tools::redirectLink($url);
			    }
			}
		} elseif (Tools::getIsset('moderate')) {
		    if($moderator) {
		        $url = 'http' . (isset($_SERVER['HTTPS']) ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
		        if($comment_id = Tools::getValue('comment_id')) {
		            if(!Validate::isUnsignedInt($comment_id)) {
		                $errors[] = $this->l('Wrong comment ID');
		            } else {
		                if(Tools::isSubmit('changeCommentStatus')) {
		                    $this->changeStatus($comment_id) ? Tools::redirectLink($url) : $errors[] = $this->l('Could not change comment\'s status.');
		                } elseif(Tools::isSubmit('deleteComment')) {
		                    $this->deleteComment($comment_id) ? Tools::redirectLink($url) : $errors[] = $this->l('Could not delete comment');
		                }
		            }
		        } else {
		            $errors[] = $this->l('No comment ID passed, ignoring action');
		        }
		    } else {
		        $errors[] = $this->l('You are not authorized for such action.');
		    }
		}
	}

    public function hookNewsFooter($params)
    {
		global $smarty, $cookie, $nbProducts;
		$moderator = $this->checkIfModerator(intval($cookie->id_customer), intval($this->_configuration['NEWSCOMMENTS_ADGROUP']));
		$confirmation = Tools::getValue('comment', false);
		$confirmationMessage = false;
		if($confirmation) {
		    switch($confirmation) {
		        case 'p':
		            $confirmationMessage = $this->l('Comment posted successfully.');
		            break;
		        case 'pv':
		            $confirmationMessage = $this->l('Comment posted successfully, awaiting moderator validation.');
		            break;
		    }
		}
		$smarty->assign(array(
			'logged'            => intval($cookie->id_customer) ? intval($cookie->id_customer) : false,
			'moderator'         => $moderator,
			'confirmation'      => $confirmationMessage ? $confirmationMessage : false,
			'allowguest'        => intval($this->_configuration['NEWSCOMMENTS_ALLOWGUEST']) == 1 ? true : false,
			'captchaguest'      => intval($this->_configuration['NEWSCOMMENTS_CAPTCHAGUEST']) == 1 ? true : false,
			'captchareg'        => intval($this->_configuration['NEWSCOMMENTS_CAPTCHAREG']) == 1 ? true : false,
            'session_name'      => session_name(),
            'session_id'        => session_id(),
			'action_url'        => $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'],
			'comments'          => NewsComment::getByEntry(intval($_GET['id_entry'])),
			'comment_tpl'       => _PS_MODULE_DIR_. $this->name . '/comment.tpl',
			'news_comment_path' => $this->_path
		));
		return ($this->display(__FILE__, '/newscomments.tpl'));
	}

	public function hookHeader()
	{
        session_start();
		$this->_frontOfficePostProcess();
	}
    
}
?>
